SystemOrganization addCategory: #'Zodiac-Tests'!

TestCase subclass: #ZdcAbstractSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcAbstractSocketStreamTests commentStamp: '' prior: 0!
ZdcAbstractSocketStreamTests holds units tests for socket streams.

This is an abstract class, subclasses should implement #socketStreamClass !

!ZdcAbstractSocketStreamTests class methodsFor: 'testing' stamp: ''!
isAbstract 
	^ true! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
bytes: size
	| count data pattern |
	count := 0.
	pattern := (0 to: 255) asByteArray.
	data := ByteArray streamContents: [ :stream |
		[ count < size ] whileTrue: [
			stream nextPutAll: pattern.
			count := count + pattern size ] ].
	^ data copyFrom: 1 to: size     ! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
listenBacklogSize
	"Server socket backlog size (number of pending connection waiting to be accepted)"
	
	^ 32! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
openConnectionToHost: host port: port
	^ self socketStreamClass 
		openConnectionToHost: host port: port! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
openConnectionToHostNamed: host port: port
	^ self socketStreamClass 
		openConnectionToHostNamed: host port: port! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
port 
	^ 1701! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
referenceSocketStreamOn: socket
	| stream |
	stream := SocketStream on: socket.
	self setReferenceSocketStreamOptions: stream.
	^ stream! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
runClient: block
	| semaphore |
	semaphore := Semaphore new.
	[ block ensure: [ semaphore signal ] ] forkAt: self serverPriority - 1.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
runServer: block
	| serverSocket semaphore |
	serverSocket := self serverSocketOn: self port.
	self assert: serverSocket notNil.
	self assert: serverSocket localPort = self port.
	semaphore := Semaphore new.
	[ 
	semaphore signal.
	[ block cull: serverSocket cull: semaphore ]
		ensure: [ 
			serverSocket closeAndDestroy.
			semaphore signal ] ] forkAt: self serverPriority.
	semaphore wait.
	^ semaphore! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
serverPriority
	^ Processor userBackgroundPriority! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
serverSocketOn: port
	| socket |
	(socket := Socket newTCP)
		setOption: 'TCP_NODELAY' value: 1;
		setOption: 'SO_SNDBUF' value: self socketBufferSize;
		setOption: 'SO_RCVBUF' value: self socketBufferSize .
	socket listenOn: port backlogSize: self listenBacklogSize.
	socket isValid
		ifFalse: [ self error: 'Cannot create socket on port ', port printString ].
	^ socket! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
setReferenceSocketStreamOptions: stream
	stream
		binary;
		shouldSignal: true;
		autoFlush: false;
		bufferSize: self socketBufferSize;
		timeout: self socketStreamTimeout! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketBufferSize
	"Size in bytes for Sockets and SocketStream IO buffers"

	^ 4096! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamClass
	^ self subclassResponsibility ! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: ''!
socketStreamOn: socket
	^ self socketStreamClass 
		on: socket! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamTimeout
	"Timeout in seconds for SocketStream IO"
	
	^ ZnNetworkingUtils socketStreamTimeout! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testAddOneEcho
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamOn: clientSocket.
		data := stream next.
		stream nextPut: ((data + 1) bitAnd: 16rff).  
		stream close ].
	dataSent := 99.
	clientStream := self openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPut: dataSent; flush.
	dataRead := clientStream next.
	clientStream close.
	self assert: dataRead = (dataSent + 1).
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientRead
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientRead10k
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientRead10kInPieces1
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := ByteArray new: 10000 streamContents: [ :stream |
		10 timesRepeat: [ stream nextPutAll: (clientStream next: 1000) ] ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientRead10kInPieces2
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := ByteArray new: 10000.
	0 to: 9 do: [ :index | 
		clientStream next: 1000 into: dataRead startingAt: (index * 1000) + 1 ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientSkip
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		serverStream nextPut: 0; nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream skip: 1; upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientSkip10k
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		10000 timesRepeat: [ serverStream nextPut: 0 ].  
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream skip: 10000; upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientWrite
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := #[ 1 2 3 4 5 6 ].
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	clientStream nextPutAll: dataSent.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientWrite10k
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := self bytes: 10000.
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	clientStream nextPutAll: dataSent.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testPlainClientWrite10kInPieces
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self referenceSocketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := self bytes: 10000.
	clientStream := self openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	0 to: 9 do: [ :index |
		clientStream next: 1000 putAll: dataSent startingAt: (1000 * index) + 1 ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testReverseEcho
	| dataSent dataRead clientStream semaphore data |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamOn: clientSocket.
		data := stream upTo: 0.
		stream nextPutAll: data reverse; nextPut: 0.  
		stream close ].
	dataSent := #[ 1 2 3 4 5 6 ].
	clientStream := self openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; nextPut: 0; flush.
	dataRead := clientStream upTo: 0.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testReverseEcho10kFixed
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamOn: clientSocket.
		data := stream next: 10000.
		stream nextPutAll: data reverse.  
		stream close ].
	dataSent := self bytes: 10000.
	clientStream := self openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; flush.
	dataRead := clientStream next: 10000.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testReverseEcho10kSearch
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamOn: clientSocket.
		data := stream upTo: 0.
		stream nextPutAll: data reverse; nextPut: 0.  
		stream close ].
	dataSent := (self bytes: 10000) replace: [ :each | each max: 1 ].
	clientStream := self openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; nextPut: 0; flush.
	dataRead := clientStream upTo: 0.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: ''!
testReverseEchoUpToEnd
	| dataSent dataRead clientStream semaphore data |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket stream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamOn: clientSocket.
		"Doing #upToEnd here does not seem to work"
		data := stream next: 6.
		stream nextPutAll: data reverse.  
		stream close ].
	self runClient: [ 
		dataSent := #[ 1 2 3 4 5 6 ].
		clientStream := self openConnectionToHostNamed: 'localhost' port: self port.
		clientStream nextPutAll: dataSent; flush.
		dataRead := clientStream upToEnd.
		clientStream close.
		self assert: dataRead = dataSent reverse.
		semaphore wait ]! !

ZdcAbstractSocketStreamTests subclass: #ZdcOptimizedSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcOptimizedSocketStreamTests commentStamp: '' prior: 0!
ZdcOptimizedSocketStreamTests tests ZdcOptimizedSocketStream!

!ZdcOptimizedSocketStreamTests class methodsFor: 'testing' stamp: ''!
isAbstract 
	^ false! !

!ZdcOptimizedSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamClass
	^ ZdcOptimizedSocketStream ! !

ZdcAbstractSocketStreamTests subclass: #ZdcReferenceSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcReferenceSocketStreamTests commentStamp: '' prior: 0!
ZdcReferenceSocketStreamTests test the reference SocketStream in the image!

!ZdcReferenceSocketStreamTests class methodsFor: 'testing' stamp: ''!
isAbstract 
	^ false! !

!ZdcReferenceSocketStreamTests methodsFor: 'private' stamp: ''!
openConnectionToHost: host port: port
	| stream |
	stream := super openConnectionToHost: host port: port.
	self setReferenceSocketStreamOptions: stream.
	^ stream! !

!ZdcReferenceSocketStreamTests methodsFor: 'private' stamp: ''!
openConnectionToHostNamed: host port: port
	| stream |
	stream := super openConnectionToHostNamed: host port: port.
	self setReferenceSocketStreamOptions: stream.
	^ stream! !

!ZdcReferenceSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamClass
	^ SocketStream ! !

!ZdcReferenceSocketStreamTests methodsFor: 'private' stamp: ''!
socketStreamOn: socket
	| stream |
	stream := super socketStreamOn: socket.
	self setReferenceSocketStreamOptions: stream.
	^ stream	! !

ZdcAbstractSocketStreamTests subclass: #ZdcSimpleSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSimpleSocketStreamTests commentStamp: '' prior: 0!
ZdcSimpleSocketStreamTests tests ZdcSimpleSocketStream!

!ZdcSimpleSocketStreamTests class methodsFor: 'testing' stamp: ''!
isAbstract 
	^ false! !

!ZdcSimpleSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamClass
	^ ZdcSimpleSocketStream ! !

ZdcAbstractSocketStreamTests subclass: #ZdcSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSocketStreamTests commentStamp: '' prior: 0!
ZdcSocketStreamTests tests ZdcSocketStream!

!ZdcSocketStreamTests class methodsFor: 'testing' stamp: ''!
isAbstract 
	^ false! !

!ZdcSocketStreamTests methodsFor: 'accessing' stamp: ''!
socketStreamClass
	^ ZdcSocketStream ! !

TestCase subclass: #ZdcByteArrayManagerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcByteArrayManagerTests methodsFor: 'testing' stamp: ''!
testClearing
	| byteArrayManager one two |
	byteArrayManager := ZdcByteArrayManager new.
	byteArrayManager limit: 1.
	self assert: byteArrayManager totalSize equals: 0.
	one := (1 to: 10) asByteArray.
	byteArrayManager recycle: one.
	two := byteArrayManager byteArrayOfSize: 10 zero: true.
	self assert: one == two.
	self assert: two equals: (ByteArray new: 10)! !

!ZdcByteArrayManagerTests methodsFor: 'testing' stamp: ''!
testSimple
	| byteArrayManager byteArray |
	byteArrayManager := ZdcByteArrayManager new.
	byteArrayManager limit: 1.
	self assert: byteArrayManager totalSize equals: 0.
	byteArray := byteArrayManager byteArrayOfSize: 4096 zero: false.
	byteArrayManager recycle: byteArray.
	self assert: byteArrayManager totalSize equals: 4096.
	self assert: (byteArrayManager byteArrayOfSize: 4096 zero: false) == byteArray! !

TestCase subclass: #ZdcIOBufferTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcIOBufferTests commentStamp: '' prior: 0!
ZdcIOBufferTests holds unit tests for ZdcIOBuffer.!

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testAdvanceReadPointer
	| ioBuffer offset |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	3 timesRepeat: [ ioBuffer nextPut: 0 ].
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	3 timesRepeat: [ ioBuffer next ].
	offset := ioBuffer contentsStart.
	self assert: ioBuffer availableForReading = 6.
	1 to: 6 do: [ :each | 
		self assert: (ioBuffer buffer at: offset + each - 1) = each ].
	ioBuffer advanceReadPointer: 6.
	self assert: ioBuffer availableForReading = 0.
	ioBuffer compact.
	self assert: ioBuffer isEmpty     
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testAdvanceWritePointer
	| ioBuffer offset |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	offset := ioBuffer freeSpaceStart.
	1 to: 6 do: [ :each |
		ioBuffer buffer at: offset + each - 1 put: each ].
	ioBuffer advanceWritePointer: 6.
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer contents = #[1 2 3 4 5 6]
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testBivalentReading
	| data ioBuffer buffer |
	data := 'some string'.
	
	ioBuffer := ZdcIOBuffer on: data.
	ioBuffer advanceWritePointer: data size.
	buffer := ByteArray new: data size.
	ioBuffer readInto: buffer startingAt: 1 count: data size.
	self assert: buffer equals: data asByteArray.
	
	ioBuffer := ZdcIOBuffer on: data asByteArray.
	ioBuffer advanceWritePointer: data size.
	buffer := String new: data size.
	ioBuffer readInto: buffer startingAt: 1 count: data size.
	self assert: buffer equals: data.
! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testBivalentWriting
	| data ioBuffer |
	data := 'some string'.
	
	ioBuffer := ZdcIOBuffer on: (String new: data size).
	ioBuffer next: data size putAll: data asByteArray startingAt: 1.
	self assert: ioBuffer contents equals: data.
	
	ioBuffer := ZdcIOBuffer on: (ByteArray new: data size).
	ioBuffer next: data size putAll: data startingAt: 1.
	self assert: ioBuffer contents equals: data asByteArray! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testCompact
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	3 timesRepeat: [ ioBuffer next ].
	ioBuffer compact.
	self assert: ioBuffer availableForReading = 3.
	self assert: ioBuffer availableForWriting = 7.
	3 timesRepeat: [ ioBuffer next ].
	self assert: ioBuffer gapAtFront = 3.
	ioBuffer compact.
	self assert: ioBuffer isEmpty
	
		! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testCompactAtBeginning
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	ioBuffer compact.
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForWriting = 10.
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	ioBuffer compact.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.
	self assert: ioBuffer gapAtFront isZero! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testCompactAtEnd
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	10 timesRepeat: [ ioBuffer nextPut: 1 ].
	self assert: ioBuffer gapAtFront isZero.
	10 timesRepeat: [ ioBuffer next ].
	self assert: ioBuffer isFull.
	self assert: ioBuffer gapAtFront = 10.
	ioBuffer compact.
	self assert: ioBuffer isEmpty
	
		! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testCompactDoNothing
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForReading = 0.
	self assert: ioBuffer availableForWriting = 10.
	ioBuffer compact.
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForReading = 0.
	self assert: ioBuffer availableForWriting = 10.	    
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].	
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.
	ioBuffer compact.
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testNextPutAllStartingAt
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (String new: 12).
	ioBuffer next: 4 putAll: 'abcd' startingAt: 1.
	ioBuffer next: 4 putAll: 'xxxxabcdyyyy' startingAt: 5.
	ioBuffer next: 4 putAll: '--abcd' startingAt: 3.
	self assert: ioBuffer contents equals: 'abcdabcdabcd'! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testReadIntoStartingAtCount
	| data ioBuffer string |
	data := 'abcdefghijkl'.
	ioBuffer := ZdcIOBuffer on: data.
	ioBuffer advanceWritePointer: 12.
	string := String new: 12.
	ioBuffer readInto: string startingAt: 1 count: 4.
	ioBuffer readInto: string startingAt: 5 count: 4.
	ioBuffer readInto: string startingAt: 9 count: 4.
	self assert: string equals: data! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testReading
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	1 to: 3 do: [ :each | self assert: ioBuffer next = each ].
	self assert: ioBuffer contents = #[4 5 6].
	4 to: 6 do: [ :each | self assert: ioBuffer next = each ].
	self assert: ioBuffer isEmpty.
	self should: [ ioBuffer next ] raise: Error! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testString
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (String new: 10).
	($a to: $f) do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer contents = 'abcdef'.
	($a to: $f) do: [ :each | self assert: ioBuffer next = each ]
	
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: ''!
testWriting
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer size isZero.
	self assert: ioBuffer availableForWriting = 10.
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer contents = #[1 2 3 4 5 6].
	self assert: ioBuffer size = 6.
	self assert: ioBuffer availableForWriting = 4.
	7 to: 10 do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer isFull.
	self should: [ ioBuffer nextPut: 1 ] raise: Error! !

TestCase subclass: #ZdcPluginSSLSessionTests
	instanceVariableNames: 'session'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcPluginSSLSessionTests commentStamp: '' prior: 0!
ZdcPluginSSLSession Tests tests ZdcPluginSSLSession.
!

!ZdcPluginSSLSessionTests methodsFor: 'running' stamp: ''!
setUp
	super setUp.
	session := ZdcPluginSSLSession new! !

!ZdcPluginSSLSessionTests methodsFor: 'running' stamp: ''!
tearDown

	session destroy.
	session := nil.
	super tearDown ! !

!ZdcPluginSSLSessionTests methodsFor: 'tests' stamp: ''!
testCertificateName
	
	self assert: session certificateName equals: nil.
	
	session certificateName: 'myCert.pem'.
	
	self assert: session certificateName equals: 'myCert.pem'.
	
	session certificateName: 'otherCert.pem'.
	
	self assert: session certificateName equals: 'otherCert.pem'.
	
	session certificateName: nil.
	
	self assert: session certificateName equals: nil.
! !

!ZdcPluginSSLSessionTests methodsFor: 'tests' stamp: ''!
testServerName
	
	[ session serverName; serverName: nil ] on: PrimitiveFailed do: [ ^ self skip ].
	
	self assert: session serverName equals: nil.
	
	session serverName: 'pharo.org'.
	
	self assert: session serverName equals: 'pharo.org'.
	
	session serverName: 'smalltalkhub.com'.
	
	self assert: session serverName equals: 'smalltalkhub.com'.
	
	session serverName: nil.
	
	self assert: session serverName equals: nil.
! !

TestCase subclass: #ZdcSecureSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSecureSocketStreamTests commentStamp: '' prior: 0!
ZdcSecureSocketStreamTests tests ZdcSecureSocketStream !

!ZdcSecureSocketStreamTests methodsFor: 'private' stamp: ''!
isNativeSSLPluginPresent
	"Return whether the SSL VM plugin can be instanciated and intialized."
	
	^ [ ZdcPluginSSLSession new destroy. true ]
			on: ZdcPluginMissing
			do: [ false ]! !

!ZdcSecureSocketStreamTests methodsFor: 'tests' stamp: ''!
testIsNativeSSLPluginPresent
	"This test succeeds when the SSL VM plugin can be instantiated and intialized."
	
	self 
		assert: self isNativeSSLPluginPresent 
		description: 'It seems that the native VM SSL plugin cannot be instantiated and initialized. (VM plugin missing ? OS libraries missing ?)'! !

!ZdcSecureSocketStreamTests methodsFor: 'tests' stamp: ''!
testPlain
	| query stream request response |
	self isNativeSSLPluginPresent ifFalse: [ ^ self ].
	query := 'Smalltalk'.
	stream := ZdcSecureSocketStream openConnectionToHostNamed: 'encrypted.google.com' port: 443.
	[
		request := String streamContents: [ :out |
			out << 'GET /search?q=' << query << ' HTTP/1.1' << String crlf.
			out << 'Host: encrypted.google.com' << String crlf.
			out << 'Connection: close' << String crlf.
			out << String crlf ].
		stream connect.
		stream nextPutAll: request asByteArray.
		stream flush.
		response := stream upToEnd asString.
	] ensure: [ stream close ].
	self assert: (response includesSubstring: '200 OK').      
	self assert: (response includesSubstring: 'Google').
	self assert: (response includesSubstring: 'Smalltalk').      ! !
